using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace RepPP.Toolkit {
    //********************************************************************************
    //
	/// <summary>
	/// Implement the property page to pickup a Rep++ Field
	/// </summary>
    //
    //********************************************************************************
	public class FormFldControlPropPage : System.Windows.Forms.Form	{
		/// <summary>Required designer variable.</summary>
		private System.ComponentModel.Container components = null;
		/// <summary>Field control being edited</summary>
		private FldControlUtil.IFldControl          m_fldControl;
		/// <summary>true if filling the combobox</summary>
		private bool                                m_bFilling;
        private System.Windows.Forms.ComboBox       comboBoxGrpName;
        private System.Windows.Forms.ComboBox       comboBoxFldName;
        private System.Windows.Forms.Button         butOk;
        private System.Windows.Forms.Button         butCancel;
        private System.Windows.Forms.Button         butApply;
        private System.Windows.Forms.Label          labelGrpName;
        private System.Windows.Forms.Label          labelFldName;

        //********************************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
		/// <param name="fldControl">   Field control being edited</param>
        //
        //********************************************************************************
		public FormFldControlPropPage(FldControlUtil.IFldControl fldControl) {
			InitializeComponent();
		    m_fldControl     = fldControl;
		    FillGroupCombo();
		    SetApplyButtonState();
		}

        //********************************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
        //
        //********************************************************************************
		public FormFldControlPropPage()	: this(null) {
		}

        //********************************************************************************
        //
        /// <summary>
        /// Dispose:                    Dispose the object
        /// </summary>
        /// <param name="bDisposing">   true if disposing, false if GC</param>
        //
        //********************************************************************************
		protected override void Dispose(bool bDisposing) {
			if (bDisposing)	{
				if (components != null)	{
					components.Dispose();
				}
			}
			base.Dispose(bDisposing);
		}

        //********************************************************************************
        //
        /// <summary>
        /// FillGroupCombo:             Fills the group combo box with the list of groups
        /// </summary>
        //
        //********************************************************************************
        private void FillGroupCombo() {
            FldFullName         fldFullName;
            RepPP.Application   app;
            Groups              grps;
            int                 iIndex;
            
            m_bFilling = true;
            app        = (m_fldControl == null) ? null : m_fldControl.Application;
            comboBoxGrpName.Items.Clear();
            if (app != null) {
                fldFullName = m_fldControl.FieldFullName;
                grps        = app.Groups;
                foreach (Group grp in grps) {
                    comboBoxGrpName.Items.Add(grp.Name);
                }
                if (fldFullName.GroupName != String.Empty) {
                    iIndex = comboBoxGrpName.Items.IndexOf(fldFullName.GroupName);
                    comboBoxGrpName.SelectedIndex = iIndex;
                }
            }
            m_bFilling = false;
            if (comboBoxGrpName.SelectedIndex == -1 && comboBoxFldName.Items.Count != 0) {
                comboBoxGrpName.SelectedIndex = 0;
            }
            FillFieldCombo();
        }

        //********************************************************************************
        //
        /// <summary>
        /// FillFieldCombo:             Fills the field combo box with the list of fields
        /// </summary>
        //
        //********************************************************************************
        private void FillFieldCombo() {
            RepPP.Application   app;
            Group               grp;
            int                 iIndex;
            FldFullName         fldFullName;
            
            m_bFilling = true;
            app        = (m_fldControl == null) ? null : m_fldControl.Application;
            comboBoxFldName.Items.Clear();
            if (app != null) {
                fldFullName = m_fldControl.FieldFullName;
                if (comboBoxGrpName.SelectedIndex != -1) {
                    grp = app.Groups[comboBoxGrpName.SelectedItem as string];
                    if (grp != null) {
                        foreach (Field fld in grp.Fields) {
                            comboBoxFldName.Items.Add(fld.Name);
                        }
                        if (fldFullName.FieldName != String.Empty) {
                            iIndex                        = comboBoxFldName.Items.IndexOf(fldFullName.FieldName);
                            comboBoxFldName.SelectedIndex = iIndex;
                        }
                    }
                }
            }
            m_bFilling = false;
            if (comboBoxFldName.SelectedIndex == -1 && comboBoxFldName.Items.Count != 0) {
                comboBoxFldName.SelectedIndex = 0;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// SetApplyButtonState:    Enable or disable the apply button depending on the context
        /// </summary>
        //
        //********************************************************************************
        private void SetApplyButtonState() {
            bool        bState = false;
            int         iIndex1;
            int         iIndex2;
            FldFullName fldFullName;
            
            if (m_fldControl != null) {
                fldFullName = m_fldControl.FieldFullName;
                iIndex1     = comboBoxGrpName.SelectedIndex;
                iIndex2     = comboBoxFldName.SelectedIndex;
                if (iIndex1 != -1 && iIndex2 != -1) {
                    if (comboBoxGrpName.Items[iIndex1].ToString() != fldFullName.GroupName ||
                        comboBoxFldName.Items[iIndex2].ToString() != fldFullName.FieldName) {
                        bState = true;
                    }
                }
                butApply.Enabled = bState;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// Apply:          Apply the change
        /// </summary>
        //
        //********************************************************************************
        private void Apply() {
            int         iIndex1;
            int         iIndex2;
            FldFullName fldFullName;
            
            if (m_fldControl != null) {
                iIndex1 = comboBoxGrpName.SelectedIndex;
                iIndex2 = comboBoxFldName.SelectedIndex;
                if (iIndex1 != -1 && iIndex2 != -1) {
                    fldFullName             = new FldFullName(comboBoxGrpName.Items[iIndex1] as string,
                                                              comboBoxFldName.Items[iIndex2] as string);
                    if (fldFullName.GroupName != m_fldControl.FieldFullName.GroupName ||
                        fldFullName.FieldName != m_fldControl.FieldFullName.FieldName) {
                        m_fldControl.FieldFullName  = fldFullName;
                        m_fldControl.TriggerComponentChange();
                    }
                }
            }
            butApply.Enabled = false;
        }

        //********************************************************************************
        //
        /// <summary>
        /// butOk_Click:            Called when the OK button is pressed
        /// </summary>
        /// <param name="sender">   Sender object</param>
        /// <param name="e">        Event parameters</param>
        //
        //********************************************************************************
        private void butOk_Click(object sender, System.EventArgs e) {
            Apply();
        }

        //********************************************************************************
        //
        /// <summary>
        /// butApply_Click:         Called when the Apply button is pressed
        /// </summary>
        /// <param name="sender">   Sender object</param>
        /// <param name="e">        Event parameters</param>
        //
        //********************************************************************************
        private void butApply_Click(object sender, System.EventArgs e) {
            Apply();
        }

        //********************************************************************************
        //
        /// <summary>
        /// comboBoxGrpName_SelectedIndexChanged:   Called when the combobox selection is changed
        /// </summary>
        /// <param name="sender">                   Sender object</param>
        /// <param name="e">                        Event parameters</param>
        //
        //********************************************************************************
        private void comboBoxGrpName_SelectedIndexChanged(object sender, System.EventArgs e) {
            if (!m_bFilling) {
                FillFieldCombo();
                SetApplyButtonState();
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// comboBoxFldName_SelectedIndexChanged:   Called when the combobox selection is changed
        /// </summary>
        /// <param name="sender">                   Sender object</param>
        /// <param name="e">                        Event parameters</param>
        //
        //********************************************************************************
        private void comboBoxFldName_SelectedIndexChanged(object sender, System.EventArgs e) {
            if (!m_bFilling) {
                SetApplyButtonState();
            }
        }

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.comboBoxGrpName = new System.Windows.Forms.ComboBox();
            this.comboBoxFldName = new System.Windows.Forms.ComboBox();
            this.butOk = new System.Windows.Forms.Button();
            this.butCancel = new System.Windows.Forms.Button();
            this.butApply = new System.Windows.Forms.Button();
            this.labelGrpName = new System.Windows.Forms.Label();
            this.labelFldName = new System.Windows.Forms.Label();
            this.SuspendLayout();
            // 
            // comboBoxGrpName
            // 
            this.comboBoxGrpName.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.comboBoxGrpName.Location = new System.Drawing.Point(152, 32);
            this.comboBoxGrpName.Name = "comboBoxGrpName";
            this.comboBoxGrpName.Size = new System.Drawing.Size(176, 21);
            this.comboBoxGrpName.TabIndex = 0;
            this.comboBoxGrpName.SelectedIndexChanged += new System.EventHandler(this.comboBoxGrpName_SelectedIndexChanged);
            // 
            // comboBoxFldName
            // 
            this.comboBoxFldName.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.comboBoxFldName.Location = new System.Drawing.Point(152, 72);
            this.comboBoxFldName.Name = "comboBoxFldName";
            this.comboBoxFldName.Size = new System.Drawing.Size(176, 21);
            this.comboBoxFldName.TabIndex = 1;
            this.comboBoxFldName.SelectedIndexChanged += new System.EventHandler(this.comboBoxFldName_SelectedIndexChanged);
            // 
            // butOk
            // 
            this.butOk.DialogResult = System.Windows.Forms.DialogResult.OK;
            this.butOk.Location = new System.Drawing.Point(144, 144);
            this.butOk.Name = "butOk";
            this.butOk.TabIndex = 2;
            this.butOk.Text = "OK";
            this.butOk.Click += new System.EventHandler(this.butOk_Click);
            // 
            // butCancel
            // 
            this.butCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            this.butCancel.Location = new System.Drawing.Point(232, 144);
            this.butCancel.Name = "butCancel";
            this.butCancel.TabIndex = 3;
            this.butCancel.Text = "Cancel";
            // 
            // butApply
            // 
            this.butApply.Location = new System.Drawing.Point(320, 144);
            this.butApply.Name = "butApply";
            this.butApply.TabIndex = 4;
            this.butApply.Text = "Apply";
            this.butApply.Click += new System.EventHandler(this.butApply_Click);
            // 
            // labelGrpName
            // 
            this.labelGrpName.Location = new System.Drawing.Point(40, 32);
            this.labelGrpName.Name = "labelGrpName";
            this.labelGrpName.Size = new System.Drawing.Size(88, 23);
            this.labelGrpName.TabIndex = 5;
            this.labelGrpName.Text = "Group";
            // 
            // labelFldName
            // 
            this.labelFldName.Location = new System.Drawing.Point(40, 72);
            this.labelFldName.Name = "labelFldName";
            this.labelFldName.Size = new System.Drawing.Size(96, 23);
            this.labelFldName.TabIndex = 6;
            this.labelFldName.Text = "Field";
            // 
            // FormFldControlPropPage
            // 
            this.AcceptButton = this.butOk;
#if (VC70 || VC71)
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
#else
            this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
#endif
            this.CancelButton = this.butCancel;
            this.ClientSize = new System.Drawing.Size(408, 182);
            this.Controls.Add(this.labelFldName);
            this.Controls.Add(this.labelGrpName);
            this.Controls.Add(this.butApply);
            this.Controls.Add(this.butCancel);
            this.Controls.Add(this.butOk);
            this.Controls.Add(this.comboBoxFldName);
            this.Controls.Add(this.comboBoxGrpName);
            this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedToolWindow;
            this.Name = "FormFldControlPropPage";
            this.Text = "Rep++ Field Property Page";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.ResumeLayout(false);

        }
		#endregion

	} // Class
} // Namespace
