using System;
using System.ComponentModel;
using System.Web;
using System.Web.UI;
using System.Web.UI.Design;
using System.Web.UI.WebControls;
using RepPP;
using RepPP.Toolkit.Web;

namespace RepPP.Toolkit.Web {
    //********************************************************************************
    //
    /// <summary>
    /// Implement a datagrid link button which is not posting back when pushed
    /// </summary>
	//
    //********************************************************************************
    [DefaultEvent("Click")]
    [DataBindingHandler("System.Web.UI.Design.TextDataBindingHandler")]
    [ToolboxData("<{0}:ButtonNP runat=server Text=\"ButtonNP\"></{0}:ButtonNP>")]
    [DefaultProperty("Text")]
    [Designer(typeof(RepPP.Toolkit.Web.ButtonNP.ButtonNPDesigner))]
    public class ButtonNP : WebControl, IPostBackEventHandler {
        /// <summary>Object identifying the Click event in the array of event</summary>
        static private object   EventClick;
        /// <summary>Object identifying the Command event in the array of event</summary>
        static private object   EventCommand;
        /// <summary>Javacsript command to use instead of the normal postback</summary>
        private string          m_strCmd;

        //********************************************************************************
        //
        /// <summary>
        /// Static ctor
        /// </summary>
        //
        //********************************************************************************
        static ButtonNP() {
            EventClick   = new object();
            EventCommand = new object();
        }

        //********************************************************************************
        //
        /// <summary>
        /// ctor:           Class constructor
        /// </summary>
        //
        //********************************************************************************
        public ButtonNP() : base(HtmlTextWriterTag.Input) {
            JavaScriptCommand = "";
        }

        //********************************************************************************
        //
        /// <summary>
        /// AddAttributesToRender:  Add the attributes to render
        /// </summary>
        /// <param name="writer">   Stream</param>
	    //
        //********************************************************************************
        protected override void AddAttributesToRender(HtmlTextWriter writer) {
            string  strCode;
            string  strAttr;

            if (Page != null) {
                Page.VerifyRenderingInServerForm(this);
            }
            writer.AddAttribute(HtmlTextWriterAttribute.Type,   "button");
            writer.AddAttribute(HtmlTextWriterAttribute.Name,   UniqueID);
            writer.AddAttribute(HtmlTextWriterAttribute.Value,  Text);
            if (JavaScriptCommand != String.Empty) {
                writer.AddAttribute(HtmlTextWriterAttribute.Onclick, JavaScriptCommand);
                writer.AddAttribute("language", "javascript");
            } else {
                if (Page != null && CausesValidation && Page.Validators.Count > 0) {
                    strCode = "if (typeof(Page_ClientValidate) == 'function') Page_ClientValidate(); ";
                    if (Attributes.Count > 0) {
                        strAttr = Attributes["onclick"];
                        if (strAttr != null) {
                            strCode = strAttr + strCode;
                            Attributes.Remove("onclick");
                        }
                    }
                    writer.AddAttribute(HtmlTextWriterAttribute.Onclick, strCode);
                    writer.AddAttribute("language", "javascript");
                }
            }
            base.AddAttributesToRender(writer);
        }

        //********************************************************************************
        //
        /// <summary>
        /// JavaScriptCommand:          Javascript command
        /// </summary>
        //
        //********************************************************************************
        [Category("Behavior")]
        [Bindable(true)]
        [DefaultValue("")]
        [Description("The javascript command to attach.")]
        public virtual string JavaScriptCommand {
            get {
                return(m_strCmd);
            }
            set {
                m_strCmd = (value == null) ? string.Empty : value;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// OnClick:            Send the click event
        /// </summary>
        /// <param name="e">    Event argument</param>
        //
        //********************************************************************************
        protected virtual void OnClick(EventArgs e) {
            EventHandler handler;
            
            handler = (EventHandler)base.Events[ButtonNP.EventClick];
            if (handler != null) {
                handler(this, e);
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// OnCommand:          Send the Command event
        /// </summary>
        /// <param name="e">    Event argument</param>
        //
        //********************************************************************************
        protected virtual void OnCommand(CommandEventArgs e) {
            CommandEventHandler handler;
            
            handler = (CommandEventHandler)base.Events[ButtonNP.EventCommand];
            if (handler != null) {
                handler(this, e);
            }
            RaiseBubbleEvent(this, e);
        }

        //********************************************************************************
        //
        /// <summary>
        /// RenderContents:             Render the content
        /// </summary>
        /// <param name="writer">       Stream</param>
	    //
        //********************************************************************************
        protected override void RenderContents(HtmlTextWriter writer) {
        }

        //********************************************************************************
        //
        /// <summary>
        /// RaisePostBackEvent:             Raise a postback event
        /// </summary>
        /// <param name="strEventArgument"> Event argument</param>
        //
        //********************************************************************************
        void IPostBackEventHandler.RaisePostBackEvent(string strEventArgument) {
            if (CausesValidation) {
                Page.Validate();
            }
            OnClick(new EventArgs());
            OnCommand(new CommandEventArgs(this.CommandName, this.CommandArgument));
        }

        //********************************************************************************
        //
        /// <summary>
        /// CausesValidation:           Determines if validation occurs when a postback is received
        /// </summary>
        //
        //********************************************************************************
        [Category("Behavior")]
        [Description("Whether the button causes validation to fire.")]
        [Bindable(false)]
        [DefaultValue(true)]
        public bool CausesValidation {
            get {
                bool    bRetVal;
                object  obj;
                
                obj = ViewState["CausesValidation"];
                bRetVal = (obj != null) ? (bool)obj : true;
                return(bRetVal);
            }
            set {
                ViewState["CausesValidation"] = value;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// CommandArgument:    The command argument associated with the button.
        /// </summary>
        //
        //********************************************************************************
        [Bindable(true)]
        [Description("The command argument associated with the button.")]
        [Category("Behavior")]
        [DefaultValue("")]
        public string CommandArgument {
            get {
                string  strRetVal;
                
                strRetVal = (string)ViewState["CommandArgument"];
                if (strRetVal == null) {
                    strRetVal = String.Empty;
                }
                return(strRetVal);
            }
            set {
                ViewState["CommandArgument"] = value;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// CommandName:    The command associated with the button
        /// </summary>
        //
        //********************************************************************************
        [Category("Behavior")]
        [Description("The command associated with the button")]
        [DefaultValue("")]
        public string CommandName {
            get {
                string  strRetVal;
                
                strRetVal = (string)ViewState["CommandName"];
                if (strRetVal == null) {
                    strRetVal = String.Empty;
                }
                return(strRetVal);
            }
            set {
                ViewState["CommandName"] = value;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// Text:                       Text of the link
        /// </summary>
	    //
        //********************************************************************************
        [Category("Appearance")]
        [Bindable(true)]
        [DefaultValue("")]
        [Description("The text to be show for the link.")]
        public virtual string Text {
            get {
                string  strRetVal;
                object  obj;
                
                obj = ViewState["Text"];
                strRetVal = (obj != null) ? (string)obj : string.Empty;
                return(strRetVal);
            }
            set {
                if (HasControls()) {
                    Controls.Clear();
                }
                ViewState["Text"] = value;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// Click:      Delegate for Click event
        /// </summary>
        //
        //********************************************************************************
        [Description("Fires when the button is clicked.")]
        [Category("Action")]
        public event EventHandler Click {
            add {
                base.Events.AddHandler(ButtonNP.EventClick, value);
            }
            remove {
                base.Events.RemoveHandler(ButtonNP.EventClick, value);
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// Command:    Delegate for Command event
        /// </summary>
        //
        //********************************************************************************
        [Description("Fires when the button is clicked and an associated command is defined.")]
        [Category("Action")]
        public event EventHandler Command {
            add {
                base.Events.AddHandler(ButtonNP.EventCommand, value);
            }
            remove {
                base.Events.RemoveHandler(ButtonNP.EventCommand, value);
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// Designer for ButtonNP
        /// </summary>
        //
        //********************************************************************************
        public class ButtonNPDesigner : ControlDesigner {

            //********************************************************************************
            //
            /// <summary>
            /// ctor:       Class constuctor
            /// </summary>
            //
            //********************************************************************************
            public ButtonNPDesigner() {
            }

            //********************************************************************************
            //
            /// <summary>
            /// GetDesignTimeHtml:  Gets design time HTML
            /// </summary>
            /// <returns>
            /// Design time HTML
            /// </returns>
            //
            //********************************************************************************
            public override string GetDesignTimeHtml() {
                string      strRetVal;
                ButtonNP    but;
                string      strText;
                bool        bEmpty;
                
                but     = (ButtonNP)base.Component;
                strText = but.Text;
                bEmpty  = strText.Trim().Length == 0;
                if (bEmpty) {
                    but.Text = "[" + but.ID + "]";
                }
                strRetVal = base.GetDesignTimeHtml();
                if (bEmpty) {
                    but.Text = strText;
                }
                return(strRetVal);
            }
        }
	}
}
