using System;
using System.ComponentModel;
using System.Web;
using System.Web.UI;
using System.Web.UI.Design;
using System.Web.UI.WebControls;
using RepPP;
using RepPP.Toolkit.Web;

namespace RepPP.Toolkit.Web {
    //********************************************************************************
    //
    /// <summary>
    /// Implement a LinkButton class which can also be used without a postback. If
    /// the JavaScriptCommand property is set, the postback doesn't occurs.
    /// </summary>
	//
    //********************************************************************************
    [Designer(typeof(System.Web.UI.Design.WebControls.LinkButtonDesigner))]
    [DataBindingHandler(typeof(System.Web.UI.Design.TextDataBindingHandler))]
    [ControlBuilder(typeof(LinkButtonControlBuilder))]    
    [DefaultEvent("Click")]
    [ToolboxData("<{0}:LinkButtonNP runat=server>LinkButtonNP</{0}:LinkButtonNP>")]
    [ParseChildren(false)]
    [DefaultProperty("Text")]
    public class LinkButtonNP : WebControl, IPostBackEventHandler {
        /// <summary>Object identifying the Click event in the array of event</summary>
        static private object   EventClick;
        /// <summary>Object identifying the Command event in the array of event</summary>
        static private object   EventCommand;
        ///<summary>Javascript command</summary>
        private string          m_strCmd;

        //********************************************************************************
        //
        /// <summary>
        /// Static ctor
        /// </summary>
        //
        //********************************************************************************
        static LinkButtonNP() {
            EventClick   = new object();
            EventCommand = new object();
        }

        //********************************************************************************
        //
        /// <summary>
        /// ctor:           Class constructor
        /// </summary>
        //
        //********************************************************************************
        public LinkButtonNP() : base(HtmlTextWriterTag.A) {
            JavaScriptCommand = "";
        }

        //********************************************************************************
        //
        /// <summary>
        /// AddAttributesToRender:  Add the attributes to render
        /// </summary>
        /// <param name="writer">   Stream</param>
	    //
        //********************************************************************************
        protected override void AddAttributesToRender(HtmlTextWriter writer) {
            string  str;
            
            if (Page != null) {
                Page.VerifyRenderingInServerForm(this);
            }
            base.AddAttributesToRender(writer);
            if (Enabled && Page != null) {
                if (JavaScriptCommand != String.Empty) {
                    writer.AddAttribute(HtmlTextWriterAttribute.Onclick, JavaScriptCommand);
                    writer.AddAttribute("language", "javascript");
                } else {
                    if (CausesValidation && Page.Validators.Count > 0) {
                        str = WebUtil.GetPostBackEventReference(Page, this, String.Empty);
                        str = "{if (typeof(Page_ClientValidate) != 'function' ||  Page_ClientValidate()) " + str + "} ";
                        writer.AddAttribute(HtmlTextWriterAttribute.Href, "javascript:" + str);
                    } else {
                        writer.AddAttribute(HtmlTextWriterAttribute.Href, WebUtil.GetPostBackClientHyperlink(Page, this, ""));
                    }
                }
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// JavaScriptCommand:          Javascript command
        /// </summary>
        //
        //********************************************************************************
        [Category("Behavior")]
        [Bindable(true)]
        [DefaultValue("")]
        [Description("The javascript command to attach.")]
        public virtual string JavaScriptCommand {
            get {
                return(m_strCmd);
            }
            set {
                m_strCmd = (value == null) ? string.Empty : value;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// AddParsedSubObject:     Add sub object
        /// </summary>
        /// <param name="obj">      Object to add</param>
	    //
        //********************************************************************************
        protected override void AddParsedSubObject(object obj) {
            string strText;
            
            if (HasControls()) {
                base.AddParsedSubObject(obj);
            } else if (obj is LiteralControl) {
                Text = ((LiteralControl)obj).Text;
            } else {
                strText = Text;
                if (strText.Length != 0) {
                    Text = string.Empty;
                    base.AddParsedSubObject(new LiteralControl(strText));
                }
                base.AddParsedSubObject(obj);
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// LoadViewState:              Load the view state
        /// </summary>
        /// <param name="savedState">   State</param>
	    //
        //********************************************************************************
        protected override void LoadViewState(object savedState) {
            string  strText;
            
            if (savedState != null) {
                base.LoadViewState(savedState);
                strText = (string)ViewState["Text"];
                if (strText != null) {
                    Text = strText;
                }
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// OnClick:            Send the click event
        /// </summary>
        /// <param name="e">    Event argument</param>
        //
        //********************************************************************************
        protected virtual void OnClick(EventArgs e) {
            EventHandler handler;
            
            handler = (EventHandler)base.Events[LinkButtonNP.EventClick];
            if (handler != null) {
                handler(this, e);
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// OnCommand:          Send the Command event
        /// </summary>
        /// <param name="e">    Event argument</param>
        //
        //********************************************************************************
        protected virtual void OnCommand(CommandEventArgs e) {
            CommandEventHandler handler;
            
            handler = (CommandEventHandler)base.Events[LinkButtonNP.EventCommand];
            if (handler != null) {
                handler(this, e);
            }
            RaiseBubbleEvent(this, e);
        }

        //********************************************************************************
        //
        /// <summary>
        /// OnPreRender:        Called before the rendering of the control
        /// </summary>
        /// <param name="e">    Event parameter</param>
        //
        //********************************************************************************
        protected override void OnPreRender(EventArgs e) {
            base.OnPreRender(e);
            if (Page != null && Enabled) {
				WebUtil.GetPostBackEventReference(Page, this, "");
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// RenderContents:             Render the content
        /// </summary>
        /// <param name="writer">       Stream</param>
	    //
        //********************************************************************************
        protected override void RenderContents(HtmlTextWriter writer) {
            if (HasControls()) {
                base.RenderContents(writer);
            } else {
                writer.Write(Text);
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// RaisePostBackEvent:             Raise a postback event
        /// </summary>
        /// <param name="strEventArgument"> Event argument</param>
        //
        //********************************************************************************
        void IPostBackEventHandler.RaisePostBackEvent(string strEventArgument) {
            if (CausesValidation) {
                Page.Validate();
            }
            OnClick(new EventArgs());
            OnCommand(new CommandEventArgs(this.CommandName, this.CommandArgument));
        }

        //********************************************************************************
        //
        /// <summary>
        /// CausesValidation:           Determines if validation occurs when a postback is received
        /// </summary>
        //
        //********************************************************************************
        [Category("Behavior")]
        [Description("Whether the button causes validation to fire.")]
        [Bindable(false)]
        [DefaultValue(true)]
        public bool CausesValidation {
            get {
                bool    bRetVal;
                object  obj;
                
                obj = ViewState["CausesValidation"];
                bRetVal = (obj != null) ? (bool)obj : true;
                return(bRetVal);
            }
            set {
                ViewState["CausesValidation"] = value;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// CommandArgument:    The command argument associated with the button.
        /// </summary>
        //
        //********************************************************************************
        [Bindable(true)]
        [Description("The command argument associated with the button.")]
        [Category("Behavior")]
        [DefaultValue("")]
        public string CommandArgument {
            get {
                string  strRetVal;
                
                strRetVal = (string)ViewState["CommandArgument"];
                if (strRetVal == null) {
                    strRetVal = String.Empty;
                }
                return(strRetVal);
            }
            set {
                ViewState["CommandArgument"] = value;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// CommandName:    The command associated with the button
        /// </summary>
        //
        //********************************************************************************
        [Category("Behavior")]
        [Description("The command associated with the button")]
        [DefaultValue("")]
        public string CommandName {
            get {
                string  strRetVal;
                
                strRetVal = (string)ViewState["CommandName"];
                if (strRetVal == null) {
                    strRetVal = String.Empty;
                }
                return(strRetVal);
            }
            set {
                ViewState["CommandName"] = value;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// Text:                       Text of the link
        /// </summary>
	    //
        //********************************************************************************
        [Category("Appearance")]
        [Bindable(true)]
        [PersistenceMode(PersistenceMode.InnerDefaultProperty)]
        [DefaultValue("")]
        [Description("The text to be show for the link.")]
        public virtual string Text {
            get {
                string  strRetVal;
                object  obj;
                
                obj = ViewState["Text"];
                strRetVal = (obj != null) ? (string)obj : string.Empty;
                return(strRetVal);
            }
            set {
                if (HasControls()) {
                    Controls.Clear();
                }
                ViewState["Text"] = value;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// Click:      Delegate for Click event
        /// </summary>
        //
        //********************************************************************************
        [Description("Fires when the button is clicked.")]
        [Category("Action")]
        public event EventHandler Click {
            add {
                base.Events.AddHandler(LinkButtonNP.EventClick, value);
            }
            remove {
                base.Events.RemoveHandler(LinkButtonNP.EventClick, value);
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// Command:    Delegate for Command event
        /// </summary>
        //
        //********************************************************************************
        [Description("Fires when the button is clicked and an associated command is defined.")]
        [Category("Action")]
        public event EventHandler Command {
            add {
                base.Events.AddHandler(LinkButtonNP.EventCommand, value);
            }
            remove {
                base.Events.RemoveHandler(LinkButtonNP.EventCommand, value);
            }
        }
	}
}
