using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace RepPP.Toolkit.Web {
    //********************************************************************************
    //
	/// <summary>
	/// TemplateContextMenuLink:    Implement an ITemplate interface to add a context menu link
	///                             to a container. this class can be instantiated to set an
	///                             ItemTemplate, HeaderTemplate or FooterTemplate of a datagrid column template.
	/// </summary>
    //
    //********************************************************************************
	public class TemplateContextMenuLink : ITemplate {
        /// <summary>The context menu link image url </summary>
        private string      m_strImageUrl;
        /// <summary>Context menu to attache to the link </summary>
        private string      m_strContextMenu;

        //********************************************************************************
        //
        /// <summary>
        /// ctor:                           Class constructor
        /// </summary>
        /// <param name="strImageUrl">      Link image url</param>
        /// <param name="strContextMenu">   Context menu name to attach to the link</param>
	    //
        //********************************************************************************
		public TemplateContextMenuLink(string strImageUrl, string strContextMenu) {
            m_strImageUrl       = strImageUrl;
            m_strContextMenu    = strContextMenu;
		}

        //********************************************************************************
        //
        /// <summary>
        /// ImageUrl:   Get and Set the context menu image url
        /// </summary>
	    //
        //********************************************************************************
        public string ImageUrl {
            get {
                return(m_strImageUrl);
            }
            set {
                m_strImageUrl = value;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// ContextMenu:   Get and Set the context menu name
        /// </summary>
	    //
        //********************************************************************************
        public string ContextMenu {
            get {
                return(m_strContextMenu);
            }
            set {
                m_strContextMenu = value;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// InstantiateIn:      Instanciate the attached control in the container
        /// </summary>
	    //
        //********************************************************************************
        void ITemplate.InstantiateIn(System.Web.UI.Control container) {
            ContextMenuLink     ctxMenuLink;

            ctxMenuLink                     = new ContextMenuLink();
            ctxMenuLink.ImageUrl            = m_strImageUrl;
            ctxMenuLink.ContextMenuToOpen   = m_strContextMenu;
            container.Controls.Add(ctxMenuLink);
        }
	} // Class TemplateContextMenuLink
} // Namespace
