using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.IO;

namespace RepPP.VSNetWizard.ASPNet
{
    //******************************************************************
    //
	/// <summary>
	/// frmMain main form for ASP.Net wizard
	/// </summary>
	//
    //******************************************************************
	internal class frmMain : frmMainBase {
        private frmStep0                            m_frmStep0;         // step 0 form
        private frmStep1                            m_frmStep1;         // step 1 form
        private frmStep2                            m_frmStep2;         // step 2 form
        private frmStep3                            m_frmStep3;         // step 3 form
        private frmStep4                            m_frmStep4;         // step 4 form
        private frmStep5                            m_frmStep5;         // step 5 form

		private System.ComponentModel.Container     components = null;

        //******************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
        //
        //******************************************************************
		public frmMain() {
			InitializeComponent();
		}

        //******************************************************************
        //
        /// <summary>
        /// ctor:                           Class constructor
        /// </summary>
        /// <param name="vsApp">            Visual studio application</param>
        /// <param name="strPrjName">       Project name</param>
        /// <param name="strPrjFullName">   Project full name</param>
        /// <param name="eLang">            Language</param>
        /// <param name="eMode">            Wizard generation mode</param>
        //
        //******************************************************************
		public frmMain(EnvDTE.DTE       vsApp,
                       string           strPrjName,
                       string           strPrjFullName,
                       ProgramLanguageE eLang,
                       GenerationModeE  eMode) : base (vsApp,
                                                       strPrjName,
                                                       strPrjFullName,
                                                       eLang,
                                                       eMode) {
			InitializeComponent();
            m_frmStep0                = new frmStep0(this);
            m_frmStep1                = new frmStep1(this);
            m_frmStep2                = new frmStep2(this);
            m_frmStep3                = new frmStep3(this);
            m_frmStep4                = new frmStep4(this);
            m_frmStep5                = new frmStep5(this);
            m_frmStep0.AttachToMainPanelV();
            butBack.Enabled           = false;
            butNext.Enabled           = true;
		}

        //******************************************************************
        //
        /// <summary>
        /// Dispose:                    Dispose the form
        /// </summary>
        /// <param name="bDisposing">   true if disposing, false if finalizing</param>
        //
        //******************************************************************
        protected override void Dispose(bool bDisposing) {
            if (bDisposing) {
                if (components != null) {
                    components.Dispose();
                }
                if (m_frmStep0 != null) {
                    m_frmStep0.Dispose();
                    m_frmStep0 = null;
                }
                if (m_frmStep1 != null) {
                    m_frmStep1.Dispose();
                    m_frmStep1 = null;
                }
                if (m_frmStep2 != null) {
                    m_frmStep2.Dispose();
                    m_frmStep2 = null;
                }
                if (m_frmStep3 != null) {
                    m_frmStep3.Dispose();
                    m_frmStep3 = null;
                }
                if (m_frmStep4 != null) {
                    m_frmStep4.Dispose();
                    m_frmStep4 = null;
                }
                if (m_frmStep5 != null) {
                    m_frmStep5.Dispose();
                    m_frmStep5 = null;
                }
            }
            base.Dispose(bDisposing);
        }

        //******************************************************************
        //
        /// <summary>
        /// GenerationMode:     Generation maode(0: group, 1: card, 2: card with selection buffer)
        /// </summary>
        //
        //******************************************************************
        public GenerationModeE GenerationMode
        {
            get {
                return(m_frmStep2.GenerationMode);
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// OnButNextClick:         Handle next button click event
        /// </summary>
        /// <param name="sender">   Sender object   </param>
        /// <param name="e">        Event Arguments </param>
        //  
        //*********************************************************     
        protected override void OnButNextClick(object sender, System.EventArgs e) {
            ArrayList   arrCardNames;
            ArrayList   arrGroupNames;
            string[]    arrNames;
            bool        bError = false;

            switch(m_iCurStep) {
            case 0:
                SetStepPanelV(m_frmStep1, true);
                break;
            case 1:
                if (InitializeRepPP(m_frmStep1.System.ToUpper(),
                                    m_frmStep1.Program.ToUpper(),
                                    m_frmStep1.Connection.ToUpper(),
                                    m_frmStep1.User.ToUpper(),
                                    m_frmStep1.Password,
                                    (RepPP.LanguageCode)m_frmStep1.Language)) {
                    if (m_app.Modules["$SYSTEM", "WEBCODEGEN"] != null) {
                        SetStepPanelV(m_frmStep2, true);
                    } else {
                        MessageBox.Show("The public module WEBCODEGEN is not included in the program " +
                                        m_app.ProgramName + ". \nPlease add this module to your program before continuing.",
                                        "Rep++ ASP.NET Wizard",
                                        MessageBoxButtons.OK,
                                        MessageBoxIcon.Error);
                        m_iCurStep--;
                    }
                } else {
                    m_iCurStep--;
                }
                break;
            case 2:
                SetStepPanelV(m_frmStep3, true);
                break;
            case 3:
                if (m_frmStep3.GenTypedInstance != Utility.GenTypedInstTypeE.None) {
                    arrCardNames = new ArrayList(2);
                    arrCardNames.Add(m_frmStep2.CardName);
                    arrCardNames.Add(m_frmStep2.SBCardName);
                    arrGroupNames = new ArrayList();
                    arrNames = Utility.GetGroupNameList(m_app.Cards[m_frmStep2.CardName]);
                    arrGroupNames.AddRange(arrNames);
                    arrNames = Utility.GetGroupNameList(m_app.Cards[m_frmStep2.SBCardName]);
                    foreach (string strName in arrNames) {
                        if (!arrGroupNames.Contains(strName)) {
                            arrGroupNames.Add(strName);
                        }
                    }
                    if (!Utility.CheckForTypedInstNameClash(m_app,
                                                            arrCardNames,
                                                            arrGroupNames,
                                                            m_frmStep3.CardInstanceBaseClass,
                                                            m_frmStep3.GroupInstanceBaseClass,
                                                            m_frmStep3.CardInstanceClassPrefix,
                                                            m_frmStep3.GroupInstanceClassPrefix,
                                                            m_frmStep3.GroupInstancePropertyPrefix,
                                                            m_frmStep3.FieldPropertyPrefix, 
                                                            m_frmStep3.GenTypedInstance == Utility.GenTypedInstTypeE.TypedInstAndWSAdapter)) {
                        m_iCurStep--;
                        bError = true;
                    }
                }
                if (!bError) {
                    if (GenerationMode != GenerationModeE.sdApplication                 &&
                        Utility.GetProjectRootNamespace(m_vsApp, m_strPrjName) == String.Empty &&
                        m_frmStep3.Namespace == String.Empty) {
                        MessageBox.Show("The project does not have a root or a default namespace and no namespace is specified for the typed instances. \r\nPlease specify a namespace for the typed instances.",
                                        "Rep++ ASP.NET Wizard",
                                        MessageBoxButtons.OK,
                                        MessageBoxIcon.Error);
                        m_iCurStep--;
                    } else {
                        SetStepPanelV(m_frmStep4, true);
                    }
                }
                break;
            case 4:
                SetStepPanelV(m_frmStep5, true);
                butNext.Enabled      = false;
                butCancelFinish.Text = "&Finish";
                break;
            }
            m_iCurStep++;
        }

        //*********************************************************     
        //
        /// <summary>
        /// OnButBackClick:         Handle back button click event
        /// </summary>
        /// <param name="sender">   Sender object   </param>
        /// <param name="e">        Event Arguments </param>
        //  
        //*********************************************************     
        protected override void OnButBackClick(object sender, System.EventArgs e) {
            switch(m_iCurStep) {
            case 1:
                SetStepPanelV(m_frmStep0, false);
                butBack.Enabled = false;
                break;
            case 2:
                SetStepPanelV(m_frmStep1, false);
                break;
            case 3:
                SetStepPanelV(m_frmStep2, false);
                break;
            case 4:
                SetStepPanelV(m_frmStep3, false);
                break;
            case 5:
                SetStepPanelV(m_frmStep4, false);
                butCancelFinish.Text = "&Cancel";
                break;
            }
            m_iCurStep--;        
        }

        //*********************************************************     
        //
        /// <summary>
        /// Generate:                   Generate project items
        /// </summary>
        //  
        //*********************************************************     
        public override void Generate() {
            GeneratorBase               generator = null;
            Utility.GenTypedInstParam   genTypedInstParam;

            genTypedInstParam = new Utility.GenTypedInstParam(m_frmStep3.GenTypedInstance,
                                                              m_frmStep3.Namespace,
                                                              "",
                                                              m_frmStep3.CardInstanceBaseClass,
                                                              m_frmStep3.GroupInstanceBaseClass,
                                                              m_frmStep3.CardInstanceClassPrefix,
                                                              m_frmStep3.GroupInstanceClassPrefix,
                                                              m_frmStep3.GroupInstancePropertyPrefix,
                                                              m_frmStep3.FieldPropertyPrefix);
            switch (m_eLang) {
            case ProgramLanguageE.sdCSharp:
                generator = new GeneratorForCS(m_vsApp,
                                               m_app,
                                               genTypedInstParam,
                                               m_frmStep4.XmlTemplateFile,
                                               m_frmStep5.ReplaceFileMode);
                break;
            case ProgramLanguageE.sdVisualBasic:
                generator = new GeneratorForVB(m_vsApp,
                                               m_app,
                                               genTypedInstParam,
                                               m_frmStep4.XmlTemplateFile,
                                               m_frmStep5.ReplaceFileMode);
                break;
            default:
                break;
            }
            if (generator != null) {
                switch (m_frmStep2.GenerationMode) {
                case GenerationModeE.sdApplication:
                    generator.GenerateApplication(ref m_strPrjName, 
                                                  ref m_strPrjFullName,
                                                  m_frmStep2.CardName,
                                                  m_frmStep2.SBCardName);
                    break;
                case GenerationModeE.sdItemCard:
                    generator.GenerateCardItem(m_strPrjName, 
                                               m_frmStep2.CardName,
                                               m_frmStep2.SBCardName);
                    break;
                case GenerationModeE.sdItemGroup:
                    generator.GenerateGroupItem(m_strPrjName, m_frmStep2.GroupName);
                    break;
                default:
                    break;
                }
                m_frmStep4.SaveTempFolder();
                if (m_frmStep3.GenTypedInstance != Utility.GenTypedInstTypeE.None) {
                    Utility.GenTypedInstanceConfigFile(Utility.GetProject(m_vsApp, m_strPrjName),
                                                       m_frmStep1.System.ToUpper(),
                                                       m_frmStep1.Program.ToUpper(),
                                                       m_frmStep1.Connection.ToUpper(),
                                                       m_frmStep1.User.ToUpper(),
                                                       (RepPP.LanguageCode)m_frmStep1.Language,
                                                       genTypedInstParam.m_strCardInstClassPrefix,
                                                       genTypedInstParam.m_strGroupInstClassPrefix,
                                                       genTypedInstParam.m_strGroupInstPropPrefix,
                                                       genTypedInstParam.m_strFieldPropPrefix,
                                                       genTypedInstParam.m_strNamespace,
                                                       genTypedInstParam.m_strRootNamespace,
                                                       m_frmStep3.CardInstanceBaseClass,
                                                       m_frmStep3.GroupInstanceBaseClass,
                                                       m_frmStep3.GenTypedInstance == Utility.GenTypedInstTypeE.TypedInstAndWSAdapter);
                    m_frmStep3.SaveTypedInstParam();
                }
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// OnButCancelFinishClick:     Handle cancel/finish button click event
        /// </summary>
        /// <param name="sender">       Sender object   </param>
        /// <param name="e">            Event Arguments </param>
        //  
        //*********************************************************     
        protected override void OnButCancelFinishClick(object sender, System.EventArgs e) {
            try {
                if (butCancelFinish.Text == "&Finish") {
#if !VC8
                    Generate();
#endif
                    this.DialogResult = System.Windows.Forms.DialogResult.OK;
                } else {
                    this.DialogResult = System.Windows.Forms.DialogResult.Cancel;
                }
            } catch (System.Exception ex) {
                MessageBox.Show(ex.ToString());
            } finally {
                Close();
            }
        }
		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(frmMain));
            this.SuspendLayout();
            // 
            // pnlMain
            // 
            this.pnlMain.Name = "pnlMain";
            // 
            // butCancelFinish
            // 
            this.butCancelFinish.Name = "butCancelFinish";
            // 
            // butNext
            // 
            this.butNext.Name = "butNext";
            // 
            // butBack
            // 
            this.butBack.Name = "butBack";
            // 
            // pictureBox1
            // 
            this.pictureBox1.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("pictureBox1.BackgroundImage")));
            this.pictureBox1.Name = "pictureBox1";
            // 
            // grpBar
            // 
            this.grpBar.Name = "grpBar";
            // 
            // frmMain
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(554, 326);
            this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
            this.Name = "frmMain";
            this.Text = "Rep++ ASP.NET Web Application Wizard";
            this.ResumeLayout(false);

        }
		#endregion
	} // Class frmMain
} // Namesapce
