//*********************************************************
//
// frmStep1:    Step 1 form: Choose xml configuration file and template
//              HTML file.
//
// Author:		Maher Najah
//
// (c) 2003 by Consyst SQL Inc.
//
//
//*********************************************************
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using Microsoft.Win32;
using System.IO;

namespace RepPP.VSNetWizard.Web
{
	/// <summary>
	/// Web Step 1 form: Select the metatemplate file
	/// </summary>
	internal class frmStep1 : frmStepBase
	{
        private System.Windows.Forms.ComboBox       cboMetaTempFile;
        private System.Windows.Forms.TextBox        txtMetaTempDir;
        private System.Windows.Forms.Label          lblMetaTempDir;
        private System.Windows.Forms.Label          lblMetaTempFile;
        private System.Windows.Forms.TextBox        txtTempDir;
        private System.Windows.Forms.Label          lblTempDir;
        private System.Windows.Forms.Button         butMetaTempDir;
        private System.Windows.Forms.Button         butTempDir;
        private System.Windows.Forms.ImageList      imageList1;
        private System.ComponentModel.IContainer    components;

        //******************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
        //
        //******************************************************************
		public frmStep1()
		{
			InitializeComponent();
		}

        //******************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
        /// <param name="frmMain">      Main form</param>
        //
        //******************************************************************
		public frmStep1(frmMain frmMain) : base(frmMain)
		{
			InitializeComponent();
            butMetaTempDir.Click                 += new EventHandler(OnButMetaTempDirClick);
            txtMetaTempDir.TextChanged           += new EventHandler(OnMetaTempDirTextChanged);
            cboMetaTempFile.SelectedIndexChanged += new EventHandler(OnTempFileSelectedIndexChanged);
            butTempDir.Click                     += new EventHandler(OnButTempDirClick);
            txtTempDir.TextChanged               += new EventHandler(OnTempDirTextChanged);
            LoadTempFolderv();
		}

        //******************************************************************
        //
        /// <summary>
        /// Dispose:                    Dispose the form
        /// </summary>
        /// <param name="bDisposing">   true if disposing, false if finalizing</param>
        //
        //******************************************************************
        protected override void Dispose(bool bDisposing) 
        {
            if (bDisposing) {
                if (components != null) {
                    components.Dispose();
                }
            }
            base.Dispose(bDisposing);
        }

        //******************************************************************
        //
        /// <summary>
        /// LoadTempFolderv:            Load the last template folder used 
        /// </summary>
        //
        //******************************************************************
        public void LoadTempFolderv()
        {
            string strRepPPDir;

            txtMetaTempDir.Text = Utility.GetRegistryKeyValue(Global.WEB_WIZARD_REGKEY, "Meta Templates");
            txtTempDir.Text     = Utility.GetRegistryKeyValue(Global.WEB_WIZARD_REGKEY, "Templates");
            if (txtMetaTempDir.Text == String.Empty || txtTempDir.Text == String.Empty) {
                strRepPPDir         = Utility.GetRepPPDir();
                txtMetaTempDir.Text = Path.Combine(strRepPPDir, "HTMLDir\\Metatemplates");
                txtTempDir.Text     = Path.Combine(strRepPPDir, "HTMLDir\\Templates");
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// SaveTempFolderv:            Save the last template folder used 
        /// </summary>
        //
        //******************************************************************
        public void SaveTempFolderV()
        {
            Utility.SetRegistryKeyValue(Global.WEB_WIZARD_REGKEY, "Meta Templates", txtMetaTempDir.Text);
            Utility.SetRegistryKeyValue(Global.WEB_WIZARD_REGKEY, "Templates", txtTempDir.Text);
        }

        //******************************************************************
        //
        /// <summary>
        /// HTMLMetaTemplateFile:             HTML meta-template file name
        /// </summary>
        //
        //******************************************************************
        public string HTMLMetaTemplateFile
        {
            get {
                return(System.IO.Path.Combine(txtMetaTempDir.Text, cboMetaTempFile.Text));
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// HTMLTemplateFile:             HTML template file name
        /// </summary>
        //
        //******************************************************************
        public string HTMLTemplateFolder
        {
            get {
                return(txtTempDir.Text);
            }
        }

        //******************************************************************
        //
        /// <summary>
        /// ValidateB:                    Validate the step
        /// </summary>
        /// <returns>
        /// True:   Valid
        /// False:  Not Valid
        /// </returns>
        //
        //******************************************************************
        public override bool ValidateB()
        {
            return(cboMetaTempFile.Text.Trim() != String.Empty &&
                   txtTempDir.Text.Trim() != String.Empty);
        }

        //******************************************************************
        //
        /// <summary>
        /// FillTempFileComboBoxv:      Fill the template files combobox
        /// </summary>
        //
        //******************************************************************
        private void FillTempFileComboBoxv()
        {
            string      strDirName;
            string[]    files;

            cboMetaTempFile.Items.Clear();
            strDirName = txtMetaTempDir.Text;
            if (System.IO.Directory.Exists(strDirName)) {
                files = System.IO.Directory.GetFiles(strDirName, "*.html");
                foreach (string str in files) {
                    cboMetaTempFile.Items.Add(System.IO.Path.GetFileName(str));
                }
            }
            if (cboMetaTempFile.Items.Count > 0) {
                cboMetaTempFile.SelectedIndex = 0;
            } else {
                cboMetaTempFile.SelectedIndex = -1;
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// OnButMetaTempDirClick:      Handle meta-template folder button click event
        /// </summary>
        /// <param name="sender">       Sender object   </param>
        /// <param name="e">            Event Arguments </param>
        //  
        //*********************************************************     
        private void OnButMetaTempDirClick(object sender, System.EventArgs e)
        {
            FolderBrowserDialog dlg = new FolderBrowserDialog();

            if (dlg.ShowDialog() == DialogResult.OK) {
                txtMetaTempDir.Text = dlg.SelectedPath;
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// OnMetaTempDirTextChanged:   Handle meta-template folder text changed event
        /// </summary>
        /// <param name="sender">       Sender object   </param>
        /// <param name="e">            Event Arguments </param>
        //  
        //*********************************************************     
        private void OnMetaTempDirTextChanged(object sender, System.EventArgs e)
        {
            FillTempFileComboBoxv();
            m_frmMain.NextButton.Enabled = ValidateB();
        }

        //*********************************************************     
        //
        /// <summary>
        /// OnTempFileSelectedIndexChanged:    Handle template file selected index changed event
        /// </summary>
        /// <param name="sender">              Sender object   </param>
        /// <param name="e">                   Event Arguments </param>
        //  
        //*********************************************************     
        private void OnTempFileSelectedIndexChanged(object sender, System.EventArgs e)
        {
            m_frmMain.NextButton.Enabled = ValidateB();
        }

        //*********************************************************     
        //
        /// <summary>
        /// OnButTempDirClick:      Handle template folder button click event
        /// </summary>
        /// <param name="sender">    Sender object   </param>
        /// <param name="e">         Event Arguments </param>
        //  
        //*********************************************************     
        private void OnButTempDirClick(object sender, System.EventArgs e)
        {
            FolderBrowserDialog dlg = new FolderBrowserDialog();

            if (dlg.ShowDialog() == DialogResult.OK) {
                txtTempDir.Text = dlg.SelectedPath;
            }
        }

        //*********************************************************     
        //
        /// <summary>
        /// OnTempDirTextChanged:     Handle template folder text changed event
        /// </summary>
        /// <param name="sender">     Sender object   </param>
        /// <param name="e">          Event Arguments </param>
        //  
        //*********************************************************     
        private void OnTempDirTextChanged(object sender, System.EventArgs e)
        {
            m_frmMain.NextButton.Enabled = ValidateB();
        }
		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.components = new System.ComponentModel.Container();
            System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(frmStep1));
            this.butMetaTempDir = new System.Windows.Forms.Button();
            this.txtMetaTempDir = new System.Windows.Forms.TextBox();
            this.lblMetaTempDir = new System.Windows.Forms.Label();
            this.lblMetaTempFile = new System.Windows.Forms.Label();
            this.cboMetaTempFile = new System.Windows.Forms.ComboBox();
            this.butTempDir = new System.Windows.Forms.Button();
            this.imageList1 = new System.Windows.Forms.ImageList(this.components);
            this.txtTempDir = new System.Windows.Forms.TextBox();
            this.lblTempDir = new System.Windows.Forms.Label();
            this.pnlStep.SuspendLayout();
            this.SuspendLayout();
            // 
            // pnlStep
            // 
            this.pnlStep.Controls.Add(this.lblTempDir);
            this.pnlStep.Controls.Add(this.butTempDir);
            this.pnlStep.Controls.Add(this.txtTempDir);
            this.pnlStep.Controls.Add(this.txtMetaTempDir);
            this.pnlStep.Controls.Add(this.cboMetaTempFile);
            this.pnlStep.Controls.Add(this.lblMetaTempFile);
            this.pnlStep.Controls.Add(this.butMetaTempDir);
            this.pnlStep.Controls.Add(this.lblMetaTempDir);
            this.pnlStep.Name = "pnlStep";
            this.pnlStep.Size = new System.Drawing.Size(416, 280);
            // 
            // butMetaTempDir
            // 
            this.butMetaTempDir.BackColor = System.Drawing.SystemColors.Control;
            this.butMetaTempDir.ImageIndex = 0;
            this.butMetaTempDir.ImageList = this.imageList1;
            this.butMetaTempDir.Location = new System.Drawing.Point(376, 48);
            this.butMetaTempDir.Name = "butMetaTempDir";
            this.butMetaTempDir.Size = new System.Drawing.Size(28, 22);
            this.butMetaTempDir.TabIndex = 4;
            this.butMetaTempDir.Text = ". . .";
            // 
            // txtMetaTempDir
            // 
            this.txtMetaTempDir.Location = new System.Drawing.Point(112, 48);
            this.txtMetaTempDir.Name = "txtMetaTempDir";
            this.txtMetaTempDir.Size = new System.Drawing.Size(256, 20);
            this.txtMetaTempDir.TabIndex = 3;
            this.txtMetaTempDir.Text = "";
            // 
            // lblMetaTempDir
            // 
            this.lblMetaTempDir.Location = new System.Drawing.Point(16, 48);
            this.lblMetaTempDir.Name = "lblMetaTempDir";
            this.lblMetaTempDir.Size = new System.Drawing.Size(88, 24);
            this.lblMetaTempDir.TabIndex = 3;
            this.lblMetaTempDir.Text = "Meta Template Folder";
            // 
            // lblMetaTempFile
            // 
            this.lblMetaTempFile.Location = new System.Drawing.Point(16, 80);
            this.lblMetaTempFile.Name = "lblMetaTempFile";
            this.lblMetaTempFile.Size = new System.Drawing.Size(88, 32);
            this.lblMetaTempFile.TabIndex = 6;
            this.lblMetaTempFile.Text = "Meta Template File";
            // 
            // cboMetaTempFile
            // 
            this.cboMetaTempFile.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.cboMetaTempFile.Location = new System.Drawing.Point(112, 80);
            this.cboMetaTempFile.Name = "cboMetaTempFile";
            this.cboMetaTempFile.Size = new System.Drawing.Size(256, 21);
            this.cboMetaTempFile.Sorted = true;
            this.cboMetaTempFile.TabIndex = 5;
            // 
            // butTempDir
            // 
            this.butTempDir.BackColor = System.Drawing.SystemColors.Control;
            this.butTempDir.ImageIndex = 0;
            this.butTempDir.ImageList = this.imageList1;
            this.butTempDir.Location = new System.Drawing.Point(376, 16);
            this.butTempDir.Name = "butTempDir";
            this.butTempDir.Size = new System.Drawing.Size(28, 22);
            this.butTempDir.TabIndex = 2;
            this.butTempDir.Text = ". . .";
            // 
            // imageList1
            // 
            this.imageList1.ImageSize = new System.Drawing.Size(16, 16);
            this.imageList1.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("imageList1.ImageStream")));
            this.imageList1.TransparentColor = System.Drawing.Color.White;
            // 
            // txtTempDir
            // 
            this.txtTempDir.Location = new System.Drawing.Point(112, 16);
            this.txtTempDir.Name = "txtTempDir";
            this.txtTempDir.Size = new System.Drawing.Size(256, 20);
            this.txtTempDir.TabIndex = 1;
            this.txtTempDir.Text = "";
            // 
            // lblTempDir
            // 
            this.lblTempDir.Location = new System.Drawing.Point(16, 18);
            this.lblTempDir.Name = "lblTempDir";
            this.lblTempDir.Size = new System.Drawing.Size(88, 24);
            this.lblTempDir.TabIndex = 11;
            this.lblTempDir.Text = "Template Folder";
            // 
            // frmStep1
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(440, 302);
            this.Name = "frmStep1";
            this.Text = "frmWebStep1";
            this.pnlStep.ResumeLayout(false);
            this.ResumeLayout(false);

        }
		#endregion
	}
}
